@@ -3,7 +3,7 @@ use warnings FATAL => 'all';
 use utf8;
 
 package Amon2::Setup::Flavor::Minimum;
-use parent qw/Amon2::Setup::Flavor/;
+use parent qw(Amon2::Setup::Flavor);
 
 sub run {
     my ($self) = @_;
@@ -264,7 +264,7 @@ sub write_templates {
 <!doctype html>
 <html>
 <head>
-    <met charst="utf-8">
+    <meta charset="utf-8">
     <title><% $module %></title>
     <meta name="viewport" content="width=device-width, initial-scale=1.0">
 </head>
